<?xml version="1.0" encoding="UTF-8" ?>
<!-- This file handles variable definitions -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
  <xsl:variable name="ST_DEVICE_TIMEFRAMES">DS_DEVICE_TIMEFRAMES</xsl:variable>

  <!-- Staging Field names -->
  <xsl:variable name="dt_owning_device_key_field">dt_owning_device_key</xsl:variable>
  <xsl:variable name="dt_owning_device_type_field">dt_owning_device_type</xsl:variable>
  <xsl:variable name="dt_name_field">dt_name</xsl:variable>
  <xsl:variable name="dt_start_time_field">dt_start_time</xsl:variable>
  <xsl:variable name="dt_duration_field">dt_duration</xsl:variable>
  <xsl:variable name="dt_day_pattern_field">dt_day_pattern</xsl:variable>
  <xsl:variable name="dt_exclude_holidays_field">dt_exclude_holidays</xsl:variable>

  <!-- Device Timeframe Table Level -->
  <xsl:template match="device_timeframe">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_DEVICE_TIMEFRAMES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncDeviceTimeframeService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncDeviceTimeframeService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_DEVICE_TIMEFRAMES" />
      </xsl:call-template>
    </bean>
  </xsl:template>
  
  <!-- Device Timeframe .. Field Level -->
  <xsl:template match="dt_owning_device_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">owningDevice</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template match="dt_owning_device_type">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">owningDeviceType</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="dt_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">name</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="dt_start_time">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">startTime</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="dt_duration">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">duration</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="dt_day_pattern">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">dayPattern</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

	<xsl:template match="dt_exclude_holidays">
		<xsl:call-template name="call_fields">
			<xsl:with-param name="model_property_name">excludeHolidays</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$booleanTypeMapper" />
		</xsl:call-template>
	</xsl:template>

</xsl:stylesheet>
