<?xml version="1.0" encoding="UTF-8" ?>
<!-- This file handles variable definitions -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="xml" encoding="UTF-8"
    doctype-system="http://www.springframework.org/dtd/spring-beans.dtd"
    doctype-public="-//SPRING//DTD BEAN//EN"
    cdata-section-elements="beans" />

  <!-- Default stage table names -->
  <xsl:variable name="ST_ONE_TIME_COVERAGES">DS_ONE_TIME_COVERAGES</xsl:variable>

  <!-- Staging Field names -->
  <!-- uses the same fields as recurrent coverages -->

  <!-- One Time Only Coverages .. Table Level -->
  <xsl:template match="one_time_coverages">
    <bean>
      <xsl:attribute name="class">
        <xsl:call-template name="choose_table_synchronizer_class"/>
      </xsl:attribute>
      <xsl:call-template name="inject_staging_datasource" />
      <xsl:call-template name="choose_staging_table_name">
        <xsl:with-param name="default_name" select="$ST_ONE_TIME_COVERAGES" />
      </xsl:call-template>
      <property name="dataSynchronizationService">
        <ref bean="dataSyncGroupOneTimeScheduleService" />
      </property>
      <xsl:call-template name="inject_report_keeper"/>
      <!-- Row Synchronizer -->
      <xsl:call-template name="row_synchronizer">
        <xsl:with-param name="data_synchronization_service">dataSyncGroupOneTimeScheduleService</xsl:with-param>
        <xsl:with-param name="default_table" select="$ST_ONE_TIME_COVERAGES" />
      </xsl:call-template>
    </bean>
  </xsl:template>
  
  <!-- One Time Only Coverages .. Field Level -->
  <xsl:template match="owning_group_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">owningGroup</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncGroupService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="coverage_name">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">scheduleName</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="start_date">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">startDate</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="start_time">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">startTime</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="duration">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">duration</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$stringTypeMapper" />
    </xsl:call-template>
  </xsl:template>

  <xsl:template match="worker_team_key">
    <xsl:call-template name="call_fields">
      <xsl:with-param name="model_property_name">workerTeam</xsl:with-param>
      <xsl:with-param name="mapper_class" select="$referenceKeyTypeMapper" />
      <xsl:with-param name="mapper_properties">dataSyncTeamService</xsl:with-param>
    </xsl:call-template>
  </xsl:template>

</xsl:stylesheet>
